
module EnvManager
  class Builder

    def initialize(file_contents)
      build(file_contents)
    end

    def build(file_contents)
      hash = dynamic_assignment(file_contents)
      hash.each do |key, value|
        instance_variable_set("@#{key}", value)
        self.class.send(:attr_accessor, key)
      end
    end

    %w|development staging test production|.each do |env|
      define_method :"#{env}?" do
        env == ::ENV['RACK_ENV']
      end
    end

    def env
      ::ENV['RACK_ENV']
    end

    private

    # Builds a hash of the .env file
    # Assigns values to the ENV global
    def dynamic_assignment(content)
      return if content.nil? || content == ''
      content.split("\n").inject({}) do |hash, line|
        key, value = line.split('=')
        ::ENV[key] = value.strip

        hash[key.downcase.to_sym] = value.strip
        hash
      end
    end

  end
end